/*****************************************************************************
 * BF707_SSL.c
 *
 * Second Stage Loader for ADSP-BF707 EZ-Kit Lite
 *
 * Date: 4-14-2015
 * Author: D.Harrington
 *
 *
 *****************************************************************************/

#include "adi_initialize.h"
#include "BF707_SSL.h"
#include <cdefBF70x_rom.h>
#include <sys/platform.h>
#include <services/gpio/adi_gpio.h>
#include <stdio.h>

#define LED_3 0x40010000
#define LED_4 0x40020000

#define GPIO_MEMORY_SIZE (ADI_GPIO_CALLBACK_MEM_SIZE*2)

/* allocate memory for the GPIO service */
static uint8_t gpioMemory[GPIO_MEMORY_SIZE];

/* callback for receiving GPIO input events */
void gpioCallback(ADI_GPIO_PIN_INTERRUPT ePinInt, uint32_t PinIntData,
		void *pCBParam) {

	switch(ePinInt)
		{
		case ADI_GPIO_PIN_INTERRUPT_0:
			/* push button 1 */
			if (PinIntData & ADI_GPIO_PIN_7)
			{
				*pREG_L1IM_ICTL = 0;
				adi_rom_Boot(LED_4, 0, 0, 0, 0x207);
			}
			break;
		case ADI_GPIO_PIN_INTERRUPT_2:
			/* push button 2 */
			if (PinIntData & ADI_GPIO_PIN_2)
			{
				*pREG_L1IM_ICTL = 0;
				adi_rom_Boot(LED_3, 0, 0, 0, 0x207);
			}
			break;
		default:
			break;
		}
}



int main(void) {
	/**
	 * Initialize managed drivers and/or services that have been added to
	 * the project.
	 * @return zero on success
	 */
	adi_initComponents();

	ADI_GPIO_RESULT result;
	uint32_t gpioMaxCallbacks;

	/* initialize the GPIO service */
	result = adi_gpio_Init((void*) gpioMemory, GPIO_MEMORY_SIZE,
			&gpioMaxCallbacks);


	/* set the GPIO direction */
	result = adi_gpio_SetDirection(ADI_GPIO_PORT_A, ADI_GPIO_PIN_2,
			ADI_GPIO_DIRECTION_INPUT);
	result = adi_gpio_SetDirection(ADI_GPIO_PORT_B, ADI_GPIO_PIN_7,
			ADI_GPIO_DIRECTION_INPUT);


	/* set edge sense mode (PORT B is connected to Pin Interrupt 0) */
	result = adi_gpio_SetPinIntEdgeSense(ADI_GPIO_PIN_INTERRUPT_2,
			ADI_GPIO_PIN_2, ADI_GPIO_SENSE_RISING_EDGE);
	result = adi_gpio_SetPinIntEdgeSense(ADI_GPIO_PIN_INTERRUPT_0,
			ADI_GPIO_PIN_7, ADI_GPIO_SENSE_RISING_EDGE);

	/* register pinint 0 callback */
	result = adi_gpio_RegisterCallback(ADI_GPIO_PIN_INTERRUPT_2, ADI_GPIO_PIN_2,
			gpioCallback, (void*) 0);
	result = adi_gpio_RegisterCallback(ADI_GPIO_PIN_INTERRUPT_0, ADI_GPIO_PIN_7,
			gpioCallback, (void*) 0);


	/* enable the pin interrupt mask */
	result = adi_gpio_EnablePinInterruptMask(ADI_GPIO_PIN_INTERRUPT_2,
			ADI_GPIO_PIN_2, true);
	result = adi_gpio_EnablePinInterruptMask(ADI_GPIO_PIN_INTERRUPT_0,
			ADI_GPIO_PIN_7, true);



	/* wait for the GPIO input event */
	while (1) {
	}
}
